@@ -1,10 +1,12 @@
 # Sample R code for "PBSadmb" with the example "vonb.tpl"
 
-# Before sourcing this file, have a valid file "ADopts.txt" in the 
-# current working directory.
+# Before sourcing this file, have a valid file pathfile 
+# in the current working directory (default = "ADpaths.txt", 
+# but user can specify any file name in setupAD() ).
 
 # Load R packages; ignore the GUI for now.
-require(PBSmodelling); require(PBSadmb); readADopts("Adopts.txt")
+require(PBSmodelling); require(PBSadmb)
+setupAD()
 
 # Make and run "vonb.exe"
 makeAD("vonb"); runAD("vonb");
